@@ -5,7 +5,7 @@ import requests
 from .fs import delete
 from .fs import read
 from .fs import write
-from .fs import path
+from .fs import cwd
 
 
 
