@@ -1,4 +1,4 @@
 from .delete import delete
-from .path import path
+from .cwd import cwd
 from .read import read
 from .write import write
