@@ -3,9 +3,9 @@ import shutil, os, pathlib
 
 def write(my_path,str1):
     my_error = ""
-    # 判断绝对路径
-    if not os.path.isabs(my_path):
-        my_error = my_error + f"1请检查路径是不是绝对路径|      {my_path}"
+    # # 判断绝对路径
+    # if not os.path.isabs(my_path):
+    #     my_error = my_error + f"1请检查路径是不是绝对路径|      {my_path}"
 
     # 判断存在文件吗
     if not os.path.exists(my_path):
